@@ -1,6 +1,6 @@
 estfun.censReg <- function( x, includeSigma = TRUE, ... ) {
 
-   result <- maxLik:::estfun.maxLik( x, ... )
+   result <- NextMethod( estfun, x )
 
    if( !includeSigma ) {
       result <- result[ , colnames( result ) != "logSigma" ]
